[Bf-extensions-cvs] SVN commit: /data/svn/bf-extensions [3579] trunk/py/scripts/addons/ io_scene_obj: Last spell checking (for now).

Bastien Montagne montagne29 at wanadoo.fr
Wed Jul 4 17:52:29 CEST 2012


Revision: 3579
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-extensions&revision=3579
Author:   mont29
Date:     2012-07-04 15:52:29 +0000 (Wed, 04 Jul 2012)
Log Message:
-----------
Last spell checking (for now).

Modified Paths:
--------------
    trunk/py/scripts/addons/io_scene_obj/__init__.py
    trunk/py/scripts/addons/io_scene_obj/import_obj.py

Modified: trunk/py/scripts/addons/io_scene_obj/__init__.py
===================================================================
--- trunk/py/scripts/addons/io_scene_obj/__init__.py	2012-07-04 15:06:01 UTC (rev 3578)
+++ trunk/py/scripts/addons/io_scene_obj/__init__.py	2012-07-04 15:52:29 UTC (rev 3579)
@@ -67,7 +67,7 @@
 
     use_ngons = BoolProperty(
             name="NGons",
-            description="Import faces with more than 4 verts as fgons",
+            description="Import faces with more than 4 verts as ngons",
             default=True,
             )
     use_edges = BoolProperty(

Modified: trunk/py/scripts/addons/io_scene_obj/import_obj.py
===================================================================
--- trunk/py/scripts/addons/io_scene_obj/import_obj.py	2012-07-04 15:06:01 UTC (rev 3578)
+++ trunk/py/scripts/addons/io_scene_obj/import_obj.py	2012-07-04 15:52:29 UTC (rev 3579)
@@ -426,7 +426,7 @@
                 ):
     """
     Takes all the data gathered and generates a mesh, adding the new object to new_objects
-    deals with fgons, sharp edges and assigning materials
+    deals with ngons, sharp edges and assigning materials
     """
     from bpy_extras.mesh_utils import ngon_tessellate
 
@@ -438,7 +438,7 @@
         smooth_group_users = {context_smooth_group: {} for context_smooth_group in list(unique_smooth_groups.keys())}
         context_smooth_group_old = -1
 
     # Split fgons into tri's
     fgon_edges = {}  # Used for storing fgon keys
     if use_edges:
         edges = []
@@ -487,7 +487,7 @@
                     except KeyError:
                         edge_dict[i1, i2] = 1
 
             # FGons into triangles
             if has_ngons and len_face_vert_loc_indices > 4:
 
                 ngon_face_indices = ngon_tessellate(verts_loc, face_vert_loc_indices)
@@ -506,7 +506,7 @@
                              for ngon in ngon_face_indices]
                             )
 
                 # edges to make fgons
                 if use_ngons:
                     edge_users = {}
                     for ngon in ngon_face_indices:
@@ -438,7 +438,7 @@
         context_smooth_group_old = -1
 
-    # Split fgons into tri's
+    # Split ngons into tri's
     fgon_edges = {}  # Used for storing fgon keys
     if use_edges:
@@ -487,7 +487,7 @@
                         edge_dict[i1, i2] = 1
 
-            # FGons into triangles
+            # NGons into triangles
             if has_ngons and len_face_vert_loc_indices > 4:
 
@@ -506,7 +506,7 @@
                             )
 
-                # edges to make fgons
+                # edges to make ngons
                 if use_ngons:
                     edge_users = {}



More information about the Bf-extensions-cvs mailing list